@@ -14,4 +14,8 @@ from pip_api._hash import hash
 from pip_api._installed_distributions import installed_distributions
 
 # Import these whenever, doesn't matter
-from pip_api._parse_requirements import parse_requirements
+from pip_api._parse_requirements import (
+    Requirement,
+    UnparsedRequirement,
+    parse_requirements,
+)
